## FileMagick - Tools for files manipulation

```bash
filemagick sub __init__.py -p '__version__ = "0.0.0"' -r '__version__ = "0.1.0"'
```

For more use cases see the test cases in the `tests` directory.
